@@ -24,6 +24,7 @@ from macrometa_source_snowflake.sync_strategies.sample_data import fetch_samples
 import macrometa_source_snowflake.sync_strategies.common as common
 import macrometa_source_snowflake.sync_strategies.full_table as full_table
 import macrometa_source_snowflake.sync_strategies.incremental as incremental
+import macrometa_source_snowflake.sync_strategies.cdc as cdc
 from macrometa_source_snowflake.connection import SnowflakeConnection, create_private_key_file, delete_private_key_file
 
 LOGGER = singer.get_logger('macrometa_source_snowflake')
@@ -452,7 +453,20 @@ def do_sync_full_table(snowflake_conn, catalog_entry, state, columns, replicatio
     singer.write_message(singer.StateMessage(value=copy.deepcopy(state)))
 
 
-def sync_streams(snowflake_conn, catalog, state, replication_method):
+def do_sync_cdc(snowflake_conn, catalog_entry, state, columns, replication_method, stream_name):
+    LOGGER.info('Stream %s is using CDC replication', catalog_entry.stream)
+
+    write_schema_message(catalog_entry)
+
+    cdc.sync_table(snowflake_conn, catalog_entry, state,
+                   columns, replication_method, stream_name)
+
+    singer.write_message(singer.StateMessage(value=copy.deepcopy(state)))
+
+
+def sync_streams(snowflake_conn, catalog, state, integration, replication_method):
+    stream_name = integration['table']
+
     for catalog_entry in catalog.streams:
         columns = list(catalog_entry.schema.properties.keys())
 
@@ -488,9 +502,12 @@ def sync_streams(snowflake_conn, catalog, state, replication_method):
             elif replication_method == 'FULL_TABLE':
                 do_sync_full_table(
                     snowflake_conn, catalog_entry, state, columns, replication_method)
+            elif replication_method == 'CDC':
+                do_sync_cdc(
+                    snowflake_conn, catalog_entry, state, columns, replication_method, stream_name)
             else:
                 raise Exception(
-                    'Only INCREMENTAL and FULL TABLE replication methods are supported')
+                    'Only INCREMENTAL, FULL TABLE, and CDC replication methods are supported')
 
     state = singer.set_currently_syncing(state, None)
     singer.write_message(singer.StateMessage(value=copy.deepcopy(state)))
@@ -689,7 +706,7 @@ class SnowflakeSourceConnector(C8Connector):
                            placeholder_value='my_db.my_schema.my_table'),
             ConfigProperty('replication_method', 'Replication Method',
                            ConfigAttributeType.STRING, True, False,
-                           description='Choose from INCREMENTAL, FULL_TABLE',
+                           description='Choose from INCREMENTAL, FULL_TABLE, CDC',
                            default_value='FULL_TABLE'),
             ConfigProperty('primary_key', 'Unique Primary Key (to be used as _key for the collection)', ConfigAttributeType.STRING, False, False,
                            description='A unique primary key from the snowflake table which needs be used as _key for the collection.'
